from typing import Literal

TransitionTimingFunction = Literal[
    'linear',
    'in',
    'out',
    'in-out',
]
